use axum::{Router};
use std::net::SocketAddr;
use axum::http::Method;
use axum::routing::get;
use tower_http::cors::{Any, CorsLayer};

mod gateway;
mod http;

#[tokio::main]
async fn main() {
    tracing_subscriber::fmt::init();

    tracing::info!("Starting matrixdiscord");

    // CORS
    let cors = CorsLayer::new()
        .allow_origin(Any)
        .allow_methods([Method::GET, Method::POST, Method::PATCH, Method::OPTIONS])
        .allow_headers(Any);

    let api = Router::new()
        .nest("/v9", http::v9::routes::assemble_routes());

    let app = Router::new()
        .nest("/api", api)
        .layer(cors)

        .route("/", get(|| async { "?" }));

    let addr = SocketAddr::from(([127, 0, 0, 1], 4200));
    tracing::info!("Listening on {}", addr);

    axum::Server::bind(&addr)
        .serve(app.into_make_service())
        .await
        .expect("Waaa");
}
